@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1300';
+our $VERSION = '0.1400';
 
 use MIDI::Simple;
 use Music::Duration;
@@ -271,6 +271,17 @@ sub metronome78 {
 }
 
 
+sub flam {
+    my ($self, $spec, $patch) = @_;
+    my $x = $MIDI::Simple::Length{$spec};
+    my $y = $MIDI::Simple::Length{ $self->sixtyfourth };
+    my $z = sprintf '%0.f', ($x - $y) * 96;
+    my $accent = sprintf '%0.f', $self->score->Volume / 2;
+    $self->accent_note($accent, $self->sixtyfourth, $patch);
+    $self->note('d' . $z, $patch);
+}
+
+
 sub roll {
     my ($self, $length, $spec, $patch) = @_;
     $patch ||= $self->snare;
@@ -317,7 +328,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1300
+version 0.1400
 
 =head1 SYNOPSIS
 
@@ -340,6 +351,7 @@ version 0.1300
 
  $d->rest($d->whole);
 
+ $d->flam($d->quarter, $d->snare);
  $d->roll($d->eighth, $d->thirtysecond);
 
  $d->metronome44;  # 4/4 time for the number of bars
@@ -545,6 +557,13 @@ Add a 7/4 beat to the score.
 
 Add a 7/8 beat to the score.
 
+=head2 flam
+
+  $d->flam( $spec, $patch );
+
+Add a flam to the score, where a ghosted gracenote is played before
+the primary note.
+
 =head2 roll
 
   $d->roll( $length, $spec, $patch );
